@@ -1338,7 +1338,7 @@ gz_thread_func(gz_thread_params_t *params)
     gchar buffer[BUFLEN];
     gssize bytes;
     gint gzval;
-    gzFile *file;
+    gzFile file;
     gint success = 1;
 
 #ifdef G_OS_WIN32
@@ -1487,7 +1487,13 @@ try_gz_open (const char *filename, const char *perms, gboolean use_gzip,
         params->perms = g_strdup(perms);
         params->compress = compress;
 
-        thread = g_thread_create((GThreadFunc) gz_thread_func, params, TRUE, &error);
+#ifndef HAVE_GLIB_2_32
+        thread = g_thread_create((GThreadFunc) gz_thread_func, params,
+				 TRUE, &error);
+#else
+        thread = g_thread_new("xml_thread", (GThreadFunc) gz_thread_func,
+			      params);
+#endif
         if (!thread)
         {
             g_warning("Could not create thread for (de)compression: %s",
@@ -1636,7 +1642,7 @@ gnc_is_xml_data_file_v2(const gchar *name, gboolean *with_encoding)
 {
     if (is_gzipped_file(name))
     {
-        gzFile *file;
+        gzFile file = NULL;
         char first_chunk[256];
         int num_read;
 
