@@ -24,9 +24,9 @@
 
 #include "config.h"
 
+#include <math.h>
 #include <gnome.h>
 #include <glib/gi18n.h>
-#include <math.h>
 #ifdef G_OS_WIN32
 #include <pow.h>
 #endif
@@ -1951,7 +1951,7 @@ gnc_account_renumber_response_cb (GtkDialog *dialog,
     if (response == GTK_RESPONSE_OK)
     {
         gtk_widget_hide(data->dialog);
-        children = gnc_account_get_children(data->parent);
+        children = gnc_account_get_children_sorted(data->parent);
         prefix = gtk_editable_get_chars(GTK_EDITABLE(data->prefix), 0, -1);
         interval =
             gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data->interval));
